@@ -1,8 +1,9 @@
+# type: ignore
+
 import pymysql
 
 
-def create_db(hostname='localhost', port=3306, username=None,
-              password=None, dbname=None):
+def create_db(hostname="localhost", port=3306, username=None, password=None, dbname=None):
     """Create test database.
 
     :param hostname: string
@@ -14,17 +15,12 @@ def create_db(hostname='localhost', port=3306, username=None,
 
     """
     cn = pymysql.connect(
-        host=hostname,
-        port=port,
-        user=username,
-        password=password,
-        charset='utf8mb4',
-        cursorclass=pymysql.cursors.DictCursor
+        host=hostname, port=port, user=username, password=password, charset="utf8mb4", cursorclass=pymysql.cursors.DictCursor
     )
 
     with cn.cursor() as cr:
-        cr.execute('drop database if exists ' + dbname)
-        cr.execute('create database ' + dbname)
+        cr.execute("drop database if exists " + dbname)
+        cr.execute("create database " + dbname)
 
     cn.close()
 
@@ -44,20 +40,13 @@ def create_cn(hostname, port, password, username, dbname):
 
     """
     cn = pymysql.connect(
-        host=hostname,
-        port=port,
-        user=username,
-        password=password,
-        db=dbname,
-        charset='utf8mb4',
-        cursorclass=pymysql.cursors.DictCursor
+        host=hostname, port=port, user=username, password=password, db=dbname, charset="utf8mb4", cursorclass=pymysql.cursors.DictCursor
     )
 
     return cn
 
 
-def drop_db(hostname='localhost', port=3306, username=None,
-            password=None, dbname=None):
+def drop_db(hostname="localhost", port=3306, username=None, password=None, dbname=None):
     """Drop database.
 
     :param hostname: string
@@ -68,17 +57,11 @@ def drop_db(hostname='localhost', port=3306, username=None,
 
     """
     cn = pymysql.connect(
-        host=hostname,
-        port=port,
-        user=username,
-        password=password,
-        db=dbname,
-        charset='utf8mb4',
-        cursorclass=pymysql.cursors.DictCursor
+        host=hostname, port=port, user=username, password=password, db=dbname, charset="utf8mb4", cursorclass=pymysql.cursors.DictCursor
     )
 
     with cn.cursor() as cr:
-        cr.execute('drop database if exists ' + dbname)
+        cr.execute("drop database if exists " + dbname)
 
     close_cn(cn)
 
